# == Class: openbsd::login_conf
#
# openpbsd::login_conf manages the login.conf(5) file on OpenBSD.
# The default mount point is /module_data, which should be installed
# and populated with default configuration files from your system.
#
# Host specific files on the form <name>-${::fqdn} take precedence.
#
# === Parameters
#
# [*_mount*]
#   Meta parameter for specifying an alternate mount path.
#
# === Examples
#
#  class { 'openbsd::login_conf':
#    $_mount = '/modules/openbsd',
#  }
#
#  include openbsd::login_conf
#
class openbsd::login_conf (
  $_mount = "/module_data/openbsd/${::operatingsystemrelease}",
) {
  file { '/etc/login.conf':
    ensure => present,
    owner => 'root',
    group => 'wheel',
    mode => '0644',
    source => [
      "puppet://${_mount}/login.conf-${::fqdn}",
      "puppet://${_mount}/login.conf",
    ],
  }
}
