# == Class: openbsd::pkg_conf
#
# openpbsd::pkg_conf manages the pkg.conf(5) file on OpenBSD.
#
# === Parameters
#
# [*settings*]
#   Hash containig all settings to be applied by the template.  If a key's
#   value is an array, the entries after the first will be on the form
#   key += val.  The first setting is always key = val.
#
# === Examples
#
#  class { 'openbsd::pkg_conf':
#    settings => {
#      installpath => [
#        "file:///mnt/openbsd/${::operatingsystemrelease}/packages/${::architecture}/",
#        "ftp://ftp.eu.openbsd.org/pub/OpenBSD/${::operatingsystemrelease}/packages/${::architecture}/",
#      ],
#      ntogo => 'yes',
#    },
#  }
#
class openbsd::pkg_conf (
  $settings,
) {
  if ! is_hash($settings) {
    fail('Class[openbsd::pkg_conf]: $settings is not a hash')
  }

  file { '/etc/pkg.conf':
    owner => 'root',
    group => 'wheel',
    mode => '0644',
    content => template('openbsd/pkg.conf.erb'),
  }
}
